package com.yijia.integral.mapper;

import java.util.List;
import com.yijia.integral.domain.IntegralWares;

/**
 * 【请填写功能名称】Mapper接口
 * 
 * @author yijia
 * @date 2021-03-01
 */
public interface IntegralWaresMapper 
{
    /**
     * 查询【请填写功能名称】
     * 
     * @param id 【请填写功能名称】ID
     * @return 【请填写功能名称】
     */
    public IntegralWares selectIntegralWaresById(Long id);

    /**
     * 查询【请填写功能名称】列表
     * 
     * @param integralWares 【请填写功能名称】
     * @return 【请填写功能名称】集合
     */
    public List<IntegralWares> selectIntegralWaresList(IntegralWares integralWares);

    /**
     * 新增【请填写功能名称】
     * 
     * @param integralWares 【请填写功能名称】
     * @return 结果
     */
    public int insertIntegralWares(IntegralWares integralWares);

    /**
     * 修改【请填写功能名称】
     * 
     * @param integralWares 【请填写功能名称】
     * @return 结果
     */
    public int updateIntegralWares(IntegralWares integralWares);

    /**
     * 删除【请填写功能名称】
     * 
     * @param id 【请填写功能名称】ID
     * @return 结果
     */
    public int deleteIntegralWaresById(Long id);

    /**
     * 批量删除【请填写功能名称】
     * 
     * @param ids 需要删除的数据ID
     * @return 结果
     */
    public int deleteIntegralWaresByIds(Long[] ids);
}
